@@ -188,8 +188,8 @@ get_behav_hist=function(dat, nburn, ngibbs, nmaxclust, var.names) {
 
     behav.list[[i]]<- data.frame(bin = 1:nrow(tmp1), tmp1) %>%
       dplyr::rename_at(dplyr::vars(tidyr::starts_with('X')), ~as.character(1:ncol(tmp1))) %>%
-      tidyr::pivot_longer(-.data$bin, names_to = "behav", values_to = "prop") %>%
-      dplyr::arrange(.data$behav) %>%
+      tidyr::pivot_longer(-"bin", names_to = "behav", values_to = "prop") %>%
+      dplyr::arrange("behav") %>%
       dplyr::mutate(var = var.names[i])
   }
 
@@ -262,12 +262,15 @@ expand_behavior=function(dat, theta.estim, obs, nbehav, behav.names, behav.order
   theta.estim1<- data.frame(id = obs$id, tseg = obs$tseg, theta.estim1)
   theta.estim1$id<- as.character(theta.estim1$id)
   names(theta.estim1)<- c("id", "tseg", behav.names)  #define behaviors
-  nobs<- data.frame(id = obs$id, tseg = obs$tseg,
-                    n = dat %>%
-                      dplyr::group_by(.data$id, .data$tseg) %>%
-                      dplyr::tally() %>%
-                      dplyr::ungroup() %>%
-                      dplyr::pull(.data$n))
+
+  nobs<- data.frame(id = obs$id, tseg = obs$tseg)
+  nobs <- dplyr::left_join(x = nobs,
+                           y = dat %>%
+                             dplyr::mutate(id = as.character(id)) %>%
+                             dplyr::group_by(.data$id, .data$tseg) %>%
+                             dplyr::tally() %>%
+                             dplyr::ungroup(),
+                           by = c('id', 'tseg'))
 
 
   for (i in 1:nrow(theta.estim1)) {
@@ -294,7 +297,7 @@ expand_behavior=function(dat, theta.estim, obs, nbehav, behav.names, behav.order
   ind1<- which(names(theta.estim2) != "id")
   theta.estim2<- theta.estim2 %>%
     dplyr::mutate_at(names(theta.estim2)[ind1], as.numeric) %>%
-    dplyr::select(.data$id, .data$tseg, .data$time1, .data$date, dplyr::everything())
+    dplyr::select("id", "tseg", "time1", "date", dplyr::everything())
 
   #Change into long format
   theta.estim.long<- tidyr::pivot_longer(theta.estim2, cols = -c(1:4),
@@ -302,7 +305,7 @@ expand_behavior=function(dat, theta.estim, obs, nbehav, behav.names, behav.order
   theta.estim.long$behavior<- factor(theta.estim.long$behavior,
                                      levels = behav.names[behav.order])
   theta.estim.long<- theta.estim.long %>%
-    dplyr::arrange(.data$behavior) %>%
+    dplyr::arrange("behavior") %>%
     dplyr::mutate_at("date", lubridate::as_datetime)
 
   theta.estim.long
@@ -325,8 +328,7 @@ expand_behavior=function(dat, theta.estim, obs, nbehav, behav.names, behav.order
 #'   Columns for behavior and proportion estimates should be labeled
 #'   \emph{behavior} and \emph{prop}, respectively. Date (in POSIXct format)
 #'   should also be included as a column labeled \emph{date}.
-#' @param behav.names character. A vector of names to label each state (in
-#'   order).
+#' @param behav.names deprecated. Now taken from the \code{theta.estim.long} object.
 #'
 #' @return A data frame of all animal IDs where columns (with names from
 #'   \code{behav.names}) include proportions of each behavioral state per
@@ -367,21 +369,25 @@ expand_behavior=function(dat, theta.estim, obs, nbehav, behav.names, behav.order
 #'
 #' #Run function
 #' dat.out<- assign_behavior(dat.orig = tracks, dat.seg.list = tracks.list,
-#'                           theta.estim.long = theta.estim.long,
-#'                           behav.names = c("Encamped","ARS","Transit"))
+#'                           theta.estim.long = theta.estim.long)
 #' }
 #'
 #'
 #' @export
-assign_behavior=function(dat.orig, dat.seg.list, theta.estim.long, behav.names) {
+assign_behavior=function(dat.orig, dat.seg.list, theta.estim.long, behav.names = NULL) {
 
+  if (!is.null(behav.names)) {
+    stop("The 'behav.names' argument has been deprecated. Don't specify this argument")
+  }
   for (i in 1:length(dat.seg.list)) {
     sub<- theta.estim.long[theta.estim.long$id == unique(dat.seg.list[[i]]$id),]
     sub<- sub %>%
-      dplyr::arrange(.data$tseg, .data$date, .data$behavior) %>%
-      tidyr::pivot_wider(names_from = .data$behavior, values_from = .data$prop)
+      dplyr::arrange("tseg", "date", "behavior") %>%
+      tidyr::pivot_wider(names_from = "behavior", values_from = "prop")
+
+    behav.names1 <- unique(theta.estim.long$behavior)
     sub<- sub %>%
-      dplyr::mutate(behav = behav.names[apply(sub[,5:ncol(sub)], 1, which.max)])
+      dplyr::mutate(behav = behav.names1[apply(sub[,5:ncol(sub)], 1, which.max)])
 
 
     dat.seg.list[[i]]<- cbind(dat.seg.list[[i]], sub[,5:ncol(sub)])
@@ -397,11 +403,11 @@ assign_behavior=function(dat.orig, dat.seg.list, theta.estim.long, behav.names)
 
   #Merge behav estimates w/ original data
   dat1<- purrr::map2(dat.orig.list1, dat.seg.list,
-                     ~dplyr::left_join(.x, .y[,c("obs","tseg", behav.names, "behav")],
+                     ~dplyr::left_join(.x, .y[,c("obs","tseg", as.character(behav.names1), "behav")],
                                        by = "obs")
   ) %>%
     dplyr::bind_rows()
 
-  dat1$behav<- factor(dat1$behav, levels = behav.names)
+  dat1$behav<- factor(dat1$behav, levels = levels(behav.names1))
   dat1
 }
