@@ -549,36 +549,6 @@ traceplot=function(data, type) {
 
 #---------------------------------------------
 
-#' Internal function to find the maximum a posteriori (MAP) estimate of the MCMC
-#' chain
-#'
-#' Internal function to be used by a wrapper.
-#'
-#' @param dat numeric. A vector of log marginal likelihood values for a given
-#'   animal ID.
-#' @param nburn numeric. The size of the burn-in phase after which the MAP
-#'   estimate will be identified.
-#'
-#' @return A numeric value indicating the iteration after the burn-in phase that
-#'   holds the MAP estimate.
-#'
-#'
-#'
-#' @export
-get_MAP_internal=function(dat, nburn) {
-
-  if (which.max(dat[-1]) < nburn) {
-    MAP.est<- dat[-1] %>%
-      order(decreasing = T)
-    MAP.est<- MAP.est[MAP.est > nburn][1]
-  } else {
-    MAP.est<- which.max(dat[-1])
-  }
-
-  return(MAP.est)
-}
-#---------------------------------------------
-
 #' Find the maximum a posteriori (MAP) estimate of the MCMC chain
 #'
 #' Identify the MCMC iteration that holds the MAP estimate. This will be used to
@@ -625,13 +595,12 @@ get_MAP_internal=function(dat, nburn) {
 #' }
 #'
 #' @export
-get_MAP=function(dat, nburn) {
-  MAP.est<- vector()
-  for (i in 1:nrow(dat)) {
-    MAP.est[i]<- get_MAP_internal(dat[i,], nburn)
-  }
+get_MAP = function(dat, nburn) {
 
-  MAP.est
+  tmp <- dat[,(nburn + 2):ncol(dat)]  #subset only columns after burn-in period
+  MAP.est <- as.integer(apply(tmp, 1, function(x) which.max(x)) + nburn)  #find max LML per ID
+
+  return(MAP.est)
 }
 #---------------------------------------------
 
@@ -764,11 +733,11 @@ plot_breakpoints_behav=function(data, as_date, var_names, var_labels, brkpts) {
 
   print(
     ggplot(dat.long, aes(x=.data[[x]], y=.data$value, color=.data$var)) +
-      geom_line(na.rm = TRUE, size = 0.25) +
+      geom_line(na.rm = TRUE, linewidth = 0.25) +
       facet_wrap(~.data$var, scales = 'free', nrow = var.len, strip.position = "left") +
-      scale_color_brewer("", palette = "Dark2", guide = FALSE) +
+      scale_color_brewer("", palette = "Dark2", guide = "none") +
       geom_vline(data = breakpt, aes(xintercept = .data$breaks - 0.5),
-                 color = "black", size = 0.7, alpha = 1) +
+                 color = "black", linewidth = 0.7, alpha = 1) +
       labs(x = "\nTime", y = "") +
       ggtitle(paste(unique(data$id))) +
       theme_bw() +
@@ -986,7 +955,7 @@ prep_data=function(dat, coord.names, id) {
 #'   which can be selected from one of "secs", "mins", "hours", "days", or
 #'   "weeks".
 #'
-#' @return A data frame where new rows have been inserted to regularize the \code{date} column. This results in values provided for \code{id}, \code{date}, and {dt} while inserting NAs for all other columns. Additionally, observations with duplicate date-times are removed.
+#' @return A data frame where new rows have been inserted to regularize the \code{date} column. This results in values provided for \code{id}, \code{date}, and \code{dt} while inserting NAs for all other columns. Additionally, observations with duplicate date-times are removed.
 #'
 #' @examples
 #' #load data
